import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ApprunnerServiceConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly autoScalingConfigurationArn?: string;
    /**
     * @stability stable
     */
    readonly serviceName: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * encryption_configuration block.
     *
     * @stability stable
     */
    readonly encryptionConfiguration?: ApprunnerServiceEncryptionConfiguration[];
    /**
     * health_check_configuration block.
     *
     * @stability stable
     */
    readonly healthCheckConfiguration?: ApprunnerServiceHealthCheckConfiguration[];
    /**
     * instance_configuration block.
     *
     * @stability stable
     */
    readonly instanceConfiguration?: ApprunnerServiceInstanceConfiguration[];
    /**
     * source_configuration block.
     *
     * @stability stable
     */
    readonly sourceConfiguration: ApprunnerServiceSourceConfiguration[];
}
/**
 * @stability stable
 */
export interface ApprunnerServiceEncryptionConfiguration {
    /**
     * @stability stable
     */
    readonly kmsKey: string;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceHealthCheckConfiguration {
    /**
     * @stability stable
     */
    readonly healthyThreshold?: number;
    /**
     * @stability stable
     */
    readonly interval?: number;
    /**
     * @stability stable
     */
    readonly path?: string;
    /**
     * @stability stable
     */
    readonly protocol?: string;
    /**
     * @stability stable
     */
    readonly timeout?: number;
    /**
     * @stability stable
     */
    readonly unhealthyThreshold?: number;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceInstanceConfiguration {
    /**
     * @stability stable
     */
    readonly cpu?: string;
    /**
     * @stability stable
     */
    readonly instanceRoleArn: string;
    /**
     * @stability stable
     */
    readonly memory?: string;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationAuthenticationConfiguration {
    /**
     * @stability stable
     */
    readonly accessRoleArn?: string;
    /**
     * @stability stable
     */
    readonly connectionArn?: string;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValues {
    /**
     * @stability stable
     */
    readonly buildCommand?: string;
    /**
     * @stability stable
     */
    readonly port?: string;
    /**
     * @stability stable
     */
    readonly runtime: string;
    /**
     * @stability stable
     */
    readonly runtimeEnvironmentVariables?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly startCommand?: string;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfiguration {
    /**
     * @stability stable
     */
    readonly configurationSource: string;
    /**
     * code_configuration_values block.
     *
     * @stability stable
     */
    readonly codeConfigurationValues?: ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfigurationCodeConfigurationValues[];
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersion {
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationCodeRepository {
    /**
     * @stability stable
     */
    readonly repositoryUrl: string;
    /**
     * code_configuration block.
     *
     * @stability stable
     */
    readonly codeConfiguration?: ApprunnerServiceSourceConfigurationCodeRepositoryCodeConfiguration[];
    /**
     * source_code_version block.
     *
     * @stability stable
     */
    readonly sourceCodeVersion: ApprunnerServiceSourceConfigurationCodeRepositorySourceCodeVersion[];
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationImageRepositoryImageConfiguration {
    /**
     * @stability stable
     */
    readonly port?: string;
    /**
     * @stability stable
     */
    readonly runtimeEnvironmentVariables?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly startCommand?: string;
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfigurationImageRepository {
    /**
     * @stability stable
     */
    readonly imageIdentifier: string;
    /**
     * @stability stable
     */
    readonly imageRepositoryType: string;
    /**
     * image_configuration block.
     *
     * @stability stable
     */
    readonly imageConfiguration?: ApprunnerServiceSourceConfigurationImageRepositoryImageConfiguration[];
}
/**
 * @stability stable
 */
export interface ApprunnerServiceSourceConfiguration {
    /**
     * @stability stable
     */
    readonly autoDeploymentsEnabled?: boolean;
    /**
     * authentication_configuration block.
     *
     * @stability stable
     */
    readonly authenticationConfiguration?: ApprunnerServiceSourceConfigurationAuthenticationConfiguration[];
    /**
     * code_repository block.
     *
     * @stability stable
     */
    readonly codeRepository?: ApprunnerServiceSourceConfigurationCodeRepository[];
    /**
     * image_repository block.
     *
     * @stability stable
     */
    readonly imageRepository?: ApprunnerServiceSourceConfigurationImageRepository[];
}
/**
 * @stability stable
 */
export declare class ApprunnerService extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ApprunnerServiceConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _autoScalingConfigurationArn?;
    /**
     * @stability stable
     */
    get autoScalingConfigurationArn(): string;
    /**
     * @stability stable
     */
    set autoScalingConfigurationArn(value: string);
    /**
     * @stability stable
     */
    resetAutoScalingConfigurationArn(): void;
    /**
     * @stability stable
     */
    get autoScalingConfigurationArnInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get serviceId(): string;
    private _serviceName;
    /**
     * @stability stable
     */
    get serviceName(): string;
    /**
     * @stability stable
     */
    set serviceName(value: string);
    /**
     * @stability stable
     */
    get serviceNameInput(): string;
    /**
     * @stability stable
     */
    get serviceUrl(): string;
    /**
     * @stability stable
     */
    get status(): string;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _encryptionConfiguration?;
    /**
     * @stability stable
     */
    get encryptionConfiguration(): ApprunnerServiceEncryptionConfiguration[];
    /**
     * @stability stable
     */
    set encryptionConfiguration(value: ApprunnerServiceEncryptionConfiguration[]);
    /**
     * @stability stable
     */
    resetEncryptionConfiguration(): void;
    /**
     * @stability stable
     */
    get encryptionConfigurationInput(): ApprunnerServiceEncryptionConfiguration[] | undefined;
    private _healthCheckConfiguration?;
    /**
     * @stability stable
     */
    get healthCheckConfiguration(): ApprunnerServiceHealthCheckConfiguration[];
    /**
     * @stability stable
     */
    set healthCheckConfiguration(value: ApprunnerServiceHealthCheckConfiguration[]);
    /**
     * @stability stable
     */
    resetHealthCheckConfiguration(): void;
    /**
     * @stability stable
     */
    get healthCheckConfigurationInput(): ApprunnerServiceHealthCheckConfiguration[] | undefined;
    private _instanceConfiguration?;
    /**
     * @stability stable
     */
    get instanceConfiguration(): ApprunnerServiceInstanceConfiguration[];
    /**
     * @stability stable
     */
    set instanceConfiguration(value: ApprunnerServiceInstanceConfiguration[]);
    /**
     * @stability stable
     */
    resetInstanceConfiguration(): void;
    /**
     * @stability stable
     */
    get instanceConfigurationInput(): ApprunnerServiceInstanceConfiguration[] | undefined;
    private _sourceConfiguration;
    /**
     * @stability stable
     */
    get sourceConfiguration(): ApprunnerServiceSourceConfiguration[];
    /**
     * @stability stable
     */
    set sourceConfiguration(value: ApprunnerServiceSourceConfiguration[]);
    /**
     * @stability stable
     */
    get sourceConfigurationInput(): ApprunnerServiceSourceConfiguration[];
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
