import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface CodebuildProjectConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly badgeEnabled?: boolean;
    /**
     * @stability stable
     */
    readonly buildTimeout?: number;
    /**
     * @stability stable
     */
    readonly concurrentBuildLimit?: number;
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly encryptionKey?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly queuedTimeout?: number;
    /**
     * @stability stable
     */
    readonly serviceRole: string;
    /**
     * @stability stable
     */
    readonly sourceVersion?: string;
    /**
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * artifacts block.
     *
     * @stability stable
     */
    readonly artifacts: CodebuildProjectArtifacts[];
    /**
     * build_batch_config block.
     *
     * @stability stable
     */
    readonly buildBatchConfig?: CodebuildProjectBuildBatchConfig[];
    /**
     * cache block.
     *
     * @stability stable
     */
    readonly cache?: CodebuildProjectCache[];
    /**
     * environment block.
     *
     * @stability stable
     */
    readonly environment: CodebuildProjectEnvironment[];
    /**
     * file_system_locations block.
     *
     * @stability stable
     */
    readonly fileSystemLocations?: CodebuildProjectFileSystemLocations[];
    /**
     * logs_config block.
     *
     * @stability stable
     */
    readonly logsConfig?: CodebuildProjectLogsConfig[];
    /**
     * secondary_artifacts block.
     *
     * @stability stable
     */
    readonly secondaryArtifacts?: CodebuildProjectSecondaryArtifacts[];
    /**
     * secondary_sources block.
     *
     * @stability stable
     */
    readonly secondarySources?: CodebuildProjectSecondarySources[];
    /**
     * source block.
     *
     * @stability stable
     */
    readonly source: CodebuildProjectSource[];
    /**
     * vpc_config block.
     *
     * @stability stable
     */
    readonly vpcConfig?: CodebuildProjectVpcConfig[];
}
/**
 * @stability stable
 */
export interface CodebuildProjectArtifacts {
    /**
     * @stability stable
     */
    readonly artifactIdentifier?: string;
    /**
     * @stability stable
     */
    readonly encryptionDisabled?: boolean;
    /**
     * @stability stable
     */
    readonly location?: string;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly namespaceType?: string;
    /**
     * @stability stable
     */
    readonly overrideArtifactName?: boolean;
    /**
     * @stability stable
     */
    readonly packaging?: string;
    /**
     * @stability stable
     */
    readonly path?: string;
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectBuildBatchConfigRestrictions {
    /**
     * @stability stable
     */
    readonly computeTypesAllowed?: string[];
    /**
     * @stability stable
     */
    readonly maximumBuildsAllowed?: number;
}
/**
 * @stability stable
 */
export interface CodebuildProjectBuildBatchConfig {
    /**
     * @stability stable
     */
    readonly combineArtifacts?: boolean;
    /**
     * @stability stable
     */
    readonly serviceRole: string;
    /**
     * @stability stable
     */
    readonly timeoutInMins?: number;
    /**
     * restrictions block.
     *
     * @stability stable
     */
    readonly restrictions?: CodebuildProjectBuildBatchConfigRestrictions[];
}
/**
 * @stability stable
 */
export interface CodebuildProjectCache {
    /**
     * @stability stable
     */
    readonly location?: string;
    /**
     * @stability stable
     */
    readonly modes?: string[];
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectEnvironmentEnvironmentVariable {
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly type?: string;
    /**
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectEnvironmentRegistryCredential {
    /**
     * @stability stable
     */
    readonly credential: string;
    /**
     * @stability stable
     */
    readonly credentialProvider: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectEnvironment {
    /**
     * @stability stable
     */
    readonly certificate?: string;
    /**
     * @stability stable
     */
    readonly computeType: string;
    /**
     * @stability stable
     */
    readonly image: string;
    /**
     * @stability stable
     */
    readonly imagePullCredentialsType?: string;
    /**
     * @stability stable
     */
    readonly privilegedMode?: boolean;
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * environment_variable block.
     *
     * @stability stable
     */
    readonly environmentVariable?: CodebuildProjectEnvironmentEnvironmentVariable[];
    /**
     * registry_credential block.
     *
     * @stability stable
     */
    readonly registryCredential?: CodebuildProjectEnvironmentRegistryCredential[];
}
/**
 * @stability stable
 */
export interface CodebuildProjectFileSystemLocations {
    /**
     * @stability stable
     */
    readonly identifier?: string;
    /**
     * @stability stable
     */
    readonly location?: string;
    /**
     * @stability stable
     */
    readonly mountOptions?: string;
    /**
     * @stability stable
     */
    readonly mountPoint?: string;
    /**
     * @stability stable
     */
    readonly type?: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectLogsConfigCloudwatchLogs {
    /**
     * @stability stable
     */
    readonly groupName?: string;
    /**
     * @stability stable
     */
    readonly status?: string;
    /**
     * @stability stable
     */
    readonly streamName?: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectLogsConfigS3Logs {
    /**
     * @stability stable
     */
    readonly encryptionDisabled?: boolean;
    /**
     * @stability stable
     */
    readonly location?: string;
    /**
     * @stability stable
     */
    readonly status?: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectLogsConfig {
    /**
     * cloudwatch_logs block.
     *
     * @stability stable
     */
    readonly cloudwatchLogs?: CodebuildProjectLogsConfigCloudwatchLogs[];
    /**
     * s3_logs block.
     *
     * @stability stable
     */
    readonly s3Logs?: CodebuildProjectLogsConfigS3Logs[];
}
/**
 * @stability stable
 */
export interface CodebuildProjectSecondaryArtifacts {
    /**
     * @stability stable
     */
    readonly artifactIdentifier: string;
    /**
     * @stability stable
     */
    readonly encryptionDisabled?: boolean;
    /**
     * @stability stable
     */
    readonly location?: string;
    /**
     * @stability stable
     */
    readonly name?: string;
    /**
     * @stability stable
     */
    readonly namespaceType?: string;
    /**
     * @stability stable
     */
    readonly overrideArtifactName?: boolean;
    /**
     * @stability stable
     */
    readonly packaging?: string;
    /**
     * @stability stable
     */
    readonly path?: string;
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectSecondarySourcesAuth {
    /**
     * @stability stable
     */
    readonly resource?: string;
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectSecondarySourcesBuildStatusConfig {
    /**
     * @stability stable
     */
    readonly context?: string;
    /**
     * @stability stable
     */
    readonly targetUrl?: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectSecondarySourcesGitSubmodulesConfig {
    /**
     * @stability stable
     */
    readonly fetchSubmodules: boolean;
}
/**
 * @stability stable
 */
export interface CodebuildProjectSecondarySources {
    /**
     * @stability stable
     */
    readonly buildspec?: string;
    /**
     * @stability stable
     */
    readonly gitCloneDepth?: number;
    /**
     * @stability stable
     */
    readonly insecureSsl?: boolean;
    /**
     * @stability stable
     */
    readonly location?: string;
    /**
     * @stability stable
     */
    readonly reportBuildStatus?: boolean;
    /**
     * @stability stable
     */
    readonly sourceIdentifier: string;
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * auth block.
     *
     * @stability stable
     */
    readonly auth?: CodebuildProjectSecondarySourcesAuth[];
    /**
     * build_status_config block.
     *
     * @stability stable
     */
    readonly buildStatusConfig?: CodebuildProjectSecondarySourcesBuildStatusConfig[];
    /**
     * git_submodules_config block.
     *
     * @stability stable
     */
    readonly gitSubmodulesConfig?: CodebuildProjectSecondarySourcesGitSubmodulesConfig[];
}
/**
 * @stability stable
 */
export interface CodebuildProjectSourceAuth {
    /**
     * @stability stable
     */
    readonly resource?: string;
    /**
     * @stability stable
     */
    readonly type: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectSourceBuildStatusConfig {
    /**
     * @stability stable
     */
    readonly context?: string;
    /**
     * @stability stable
     */
    readonly targetUrl?: string;
}
/**
 * @stability stable
 */
export interface CodebuildProjectSourceGitSubmodulesConfig {
    /**
     * @stability stable
     */
    readonly fetchSubmodules: boolean;
}
/**
 * @stability stable
 */
export interface CodebuildProjectSource {
    /**
     * @stability stable
     */
    readonly buildspec?: string;
    /**
     * @stability stable
     */
    readonly gitCloneDepth?: number;
    /**
     * @stability stable
     */
    readonly insecureSsl?: boolean;
    /**
     * @stability stable
     */
    readonly location?: string;
    /**
     * @stability stable
     */
    readonly reportBuildStatus?: boolean;
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * auth block.
     *
     * @stability stable
     */
    readonly auth?: CodebuildProjectSourceAuth[];
    /**
     * build_status_config block.
     *
     * @stability stable
     */
    readonly buildStatusConfig?: CodebuildProjectSourceBuildStatusConfig[];
    /**
     * git_submodules_config block.
     *
     * @stability stable
     */
    readonly gitSubmodulesConfig?: CodebuildProjectSourceGitSubmodulesConfig[];
}
/**
 * @stability stable
 */
export interface CodebuildProjectVpcConfig {
    /**
     * @stability stable
     */
    readonly securityGroupIds: string[];
    /**
     * @stability stable
     */
    readonly subnets: string[];
    /**
     * @stability stable
     */
    readonly vpcId: string;
}
/**
 * @stability stable
 */
export declare class CodebuildProject extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: CodebuildProjectConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    private _badgeEnabled?;
    /**
     * @stability stable
     */
    get badgeEnabled(): boolean;
    /**
     * @stability stable
     */
    set badgeEnabled(value: boolean);
    /**
     * @stability stable
     */
    resetBadgeEnabled(): void;
    /**
     * @stability stable
     */
    get badgeEnabledInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get badgeUrl(): string;
    private _buildTimeout?;
    /**
     * @stability stable
     */
    get buildTimeout(): number;
    /**
     * @stability stable
     */
    set buildTimeout(value: number);
    /**
     * @stability stable
     */
    resetBuildTimeout(): void;
    /**
     * @stability stable
     */
    get buildTimeoutInput(): number | undefined;
    private _concurrentBuildLimit?;
    /**
     * @stability stable
     */
    get concurrentBuildLimit(): number;
    /**
     * @stability stable
     */
    set concurrentBuildLimit(value: number);
    /**
     * @stability stable
     */
    resetConcurrentBuildLimit(): void;
    /**
     * @stability stable
     */
    get concurrentBuildLimitInput(): number | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _encryptionKey?;
    /**
     * @stability stable
     */
    get encryptionKey(): string;
    /**
     * @stability stable
     */
    set encryptionKey(value: string);
    /**
     * @stability stable
     */
    resetEncryptionKey(): void;
    /**
     * @stability stable
     */
    get encryptionKeyInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _queuedTimeout?;
    /**
     * @stability stable
     */
    get queuedTimeout(): number;
    /**
     * @stability stable
     */
    set queuedTimeout(value: number);
    /**
     * @stability stable
     */
    resetQueuedTimeout(): void;
    /**
     * @stability stable
     */
    get queuedTimeoutInput(): number | undefined;
    private _serviceRole;
    /**
     * @stability stable
     */
    get serviceRole(): string;
    /**
     * @stability stable
     */
    set serviceRole(value: string);
    /**
     * @stability stable
     */
    get serviceRoleInput(): string;
    private _sourceVersion?;
    /**
     * @stability stable
     */
    get sourceVersion(): string;
    /**
     * @stability stable
     */
    set sourceVersion(value: string);
    /**
     * @stability stable
     */
    resetSourceVersion(): void;
    /**
     * @stability stable
     */
    get sourceVersionInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _artifacts;
    /**
     * @stability stable
     */
    get artifacts(): CodebuildProjectArtifacts[];
    /**
     * @stability stable
     */
    set artifacts(value: CodebuildProjectArtifacts[]);
    /**
     * @stability stable
     */
    get artifactsInput(): CodebuildProjectArtifacts[];
    private _buildBatchConfig?;
    /**
     * @stability stable
     */
    get buildBatchConfig(): CodebuildProjectBuildBatchConfig[];
    /**
     * @stability stable
     */
    set buildBatchConfig(value: CodebuildProjectBuildBatchConfig[]);
    /**
     * @stability stable
     */
    resetBuildBatchConfig(): void;
    /**
     * @stability stable
     */
    get buildBatchConfigInput(): CodebuildProjectBuildBatchConfig[] | undefined;
    private _cache?;
    /**
     * @stability stable
     */
    get cache(): CodebuildProjectCache[];
    /**
     * @stability stable
     */
    set cache(value: CodebuildProjectCache[]);
    /**
     * @stability stable
     */
    resetCache(): void;
    /**
     * @stability stable
     */
    get cacheInput(): CodebuildProjectCache[] | undefined;
    private _environment;
    /**
     * @stability stable
     */
    get environment(): CodebuildProjectEnvironment[];
    /**
     * @stability stable
     */
    set environment(value: CodebuildProjectEnvironment[]);
    /**
     * @stability stable
     */
    get environmentInput(): CodebuildProjectEnvironment[];
    private _fileSystemLocations?;
    /**
     * @stability stable
     */
    get fileSystemLocations(): CodebuildProjectFileSystemLocations[];
    /**
     * @stability stable
     */
    set fileSystemLocations(value: CodebuildProjectFileSystemLocations[]);
    /**
     * @stability stable
     */
    resetFileSystemLocations(): void;
    /**
     * @stability stable
     */
    get fileSystemLocationsInput(): CodebuildProjectFileSystemLocations[] | undefined;
    private _logsConfig?;
    /**
     * @stability stable
     */
    get logsConfig(): CodebuildProjectLogsConfig[];
    /**
     * @stability stable
     */
    set logsConfig(value: CodebuildProjectLogsConfig[]);
    /**
     * @stability stable
     */
    resetLogsConfig(): void;
    /**
     * @stability stable
     */
    get logsConfigInput(): CodebuildProjectLogsConfig[] | undefined;
    private _secondaryArtifacts?;
    /**
     * @stability stable
     */
    get secondaryArtifacts(): CodebuildProjectSecondaryArtifacts[];
    /**
     * @stability stable
     */
    set secondaryArtifacts(value: CodebuildProjectSecondaryArtifacts[]);
    /**
     * @stability stable
     */
    resetSecondaryArtifacts(): void;
    /**
     * @stability stable
     */
    get secondaryArtifactsInput(): CodebuildProjectSecondaryArtifacts[] | undefined;
    private _secondarySources?;
    /**
     * @stability stable
     */
    get secondarySources(): CodebuildProjectSecondarySources[];
    /**
     * @stability stable
     */
    set secondarySources(value: CodebuildProjectSecondarySources[]);
    /**
     * @stability stable
     */
    resetSecondarySources(): void;
    /**
     * @stability stable
     */
    get secondarySourcesInput(): CodebuildProjectSecondarySources[] | undefined;
    private _source;
    /**
     * @stability stable
     */
    get source(): CodebuildProjectSource[];
    /**
     * @stability stable
     */
    set source(value: CodebuildProjectSource[]);
    /**
     * @stability stable
     */
    get sourceInput(): CodebuildProjectSource[];
    private _vpcConfig?;
    /**
     * @stability stable
     */
    get vpcConfig(): CodebuildProjectVpcConfig[];
    /**
     * @stability stable
     */
    set vpcConfig(value: CodebuildProjectVpcConfig[]);
    /**
     * @stability stable
     */
    resetVpcConfig(): void;
    /**
     * @stability stable
     */
    get vpcConfigInput(): CodebuildProjectVpcConfig[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
